"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _button = _interopRequireDefault(require("./button"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Button', function () {
  it('can have a label', function () {
    expect((0, _enzyme.shallow)(_react.default.createElement(_button.default, {
      caption: "Accept"
    }))).toHaveText('Accept');
  });
  it('can have content', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.default, null, _react.default.createElement("span", null, "Accept")));
    expect(wrapper.find('span')).toExist();
    expect(wrapper.find('span')).toHaveText('Accept');
  });
  it('if it has label, content is ignored', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.default, {
      caption: "Accept"
    }, _react.default.createElement("span", null, "Ignored")));
    expect(wrapper).toHaveText('Accept');
    expect(wrapper.find('span')).not.toExist();
  });
  it('when click executes handler', function () {
    var handler = jest.fn();
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.default, {
      caption: "Accept",
      onClick: handler
    }));
    wrapper.simulate('click');
    expect(handler).toHaveBeenCalled();
  });
  it('can be disabled', function () {
    expect((0, _enzyme.shallow)(_react.default.createElement(_button.default, {
      caption: "Accept",
      disabled: true
    }))).toBeDisabled();
  });
  it('can be set as active', function () {
    expect((0, _enzyme.shallow)(_react.default.createElement(_button.default, {
      active: true,
      caption: "Accept"
    }))).toHaveClassName('active');
  });
  it('can have a custom id or class set', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_button.default, {
      caption: "Accept",
      className: "test",
      id: "test1"
    }));
    expect(wrapper).toHaveClassName('test');
    expect(wrapper).toHaveProp('id', 'test1');
  });
  it('display types include primary and link', function () {
    var element = function element(display) {
      return _react.default.createElement(_button.default, {
        caption: "Accept",
        display: display
      });
    };

    expect((0, _enzyme.shallow)(element('primary'))).toHaveClassName('primary');
    expect((0, _enzyme.shallow)(element('link'))).toHaveClassName('link');
  });
  it('type attribute for forms can be set', function () {
    var element = function element(type) {
      return _react.default.createElement(_button.default, {
        caption: "Accept",
        type: type
      });
    };

    expect((0, _enzyme.shallow)(element('submit'))).toHaveProp('type', 'submit');
    expect((0, _enzyme.shallow)(element('reset'))).toHaveProp('type', 'reset');
  });
  it('can have different sizes', function () {
    var element = function element(size) {
      return _react.default.createElement(_button.default, {
        caption: "Accept",
        size: size
      });
    };

    expect((0, _enzyme.shallow)(element('large'))).toHaveClassName('large');
    expect((0, _enzyme.shallow)(element('small'))).toHaveClassName('small');
  });
  it('can span full width', function () {
    expect((0, _enzyme.shallow)(_react.default.createElement(_button.default, {
      block: true,
      caption: "Accept"
    }))).toHaveClassName('block');
  });
});