"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _collapsible = _interopRequireDefault(require("./collapsible"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Collapsible', function () {
  beforeAll(function () {
    jest.useFakeTimers();
    _collapsible.default.prototype.getHeight = jest.fn();
  });
  afterAll(function () {
    jest.clearAllTimers();
  });
  it('it\'s a box that wraps content', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_collapsible.default, null, _react.default.createElement("div", null, "Test")));
    expect(wrapper).toHaveClassName('collapsible');
    expect(wrapper.find('div')).toHaveLength(2);
    expect(wrapper).toHaveText('Test');
  });
  it('when collapsed collapsible height is 0', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_collapsible.default, {
      collapsed: true
    }, _react.default.createElement("div", null, "Test")));
    expect(wrapper.find('.collapsible')).toHaveStyle('height', 0);
    expect(wrapper.find('.collapsible')).toHaveStyle('overflow', 'hidden');
  });
  it('when not collapsed collapsible height is the same as content', function () {
    _collapsible.default.prototype.getHeight.mockReturnValue('100px');

    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_collapsible.default, null, _react.default.createElement("div", null, "100")));
    jest.runTimersToTime(401);
    expect(wrapper.find('.collapsible')).toHaveStyle('height', '100px');
    expect(wrapper.find('.collapsible')).toHaveStyle('overflow', 'visible');
  });
  it('when not collapsed and then collapses height changes', function () {
    _collapsible.default.prototype.getHeight.mockReturnValue('100px');

    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_collapsible.default, null, _react.default.createElement("div", null, "100")));
    jest.runTimersToTime(401);
    expect(wrapper.find('.collapsible')).toHaveStyle('height', '100px');
    expect(wrapper.find('.collapsible')).toHaveStyle('overflow', 'visible'); // Collapse it

    wrapper.setProps({
      collapsed: true
    });
    jest.runTimersToTime(401);
    expect(wrapper.find('.collapsible')).toHaveStyle('height', 0);
    expect(wrapper.find('.collapsible')).toHaveStyle('overflow', 'hidden');
  });
  it('when collapsed and then decollapses height changes', function () {
    _collapsible.default.prototype.getHeight.mockReturnValue('100px');

    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_collapsible.default, {
      collapsed: true
    }, _react.default.createElement("div", null, "100")));
    jest.runTimersToTime(401);
    expect(wrapper.find('.collapsible')).toHaveStyle('height', 0);
    expect(wrapper.find('.collapsible')).toHaveStyle('overflow', 'hidden'); // Collapse it

    wrapper.setProps({
      collapsed: false
    });
    jest.runTimersToTime(401);
    wrapper.update();
    expect(wrapper.find('.collapsible')).toHaveStyle('height', '100px');
    expect(wrapper.find('.collapsible')).toHaveStyle('overflow', 'visible');
  });
  it('when not collapsed and content changes re calculate height', function () {
    _collapsible.default.prototype.getHeight.mockReturnValue('100px');

    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_collapsible.default, null, _react.default.createElement("div", null, "100")));
    expect(wrapper.find('.collapsible')).toHaveStyle('height', '100px'); // Change content

    _collapsible.default.prototype.getHeight.mockReturnValue('200px');

    wrapper.setProps({
      children: _react.default.createElement("div", null, "200")
    });
    jest.runTimersToTime(401);
    wrapper.update();
    expect(wrapper.find('.collapsible')).toHaveStyle('height', '200px');
    expect(wrapper.find('.collapsible')).toHaveStyle('overflow', 'visible');
  });
});