"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _button = _interopRequireDefault(require("../button/button"));

var _dropdown = _interopRequireDefault(require("./dropdown"));

var _testUtils = require("../utils/test-utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var options = ['red', 'green', 'blue'];
describe('Dropdown', function () {
  it('by default adds a button as trigger', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
      caption: "Menu"
    }));
    expect(wrapper.find(_button.default)).toHaveLength(1);
    expect(wrapper.find('.trigger')).toHaveLength(1);
  });
  it('wrap trigger elements', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, null, _react.default.createElement(_button.default, {
      caption: "Menu"
    })));
    expect(wrapper.find(_button.default)).toHaveLength(1);
    expect(wrapper.find('.trigger')).toHaveLength(1);
  });
  describe('options', function () {
    it('array of strings', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        isOpen: true,
        options: options
      }));
      var $options = wrapper.find('.options');
      expect(wrapper.find('.dropdown')).toHaveLength(1);
      expect(wrapper.find('.options')).toHaveLength(1);
      expect(wrapper.find('.option')).toHaveLength(3);
      expect($options.childAt(0)).toHaveText('red');
      expect($options.childAt(1)).toHaveText('green');
      expect($options.childAt(2)).toHaveText('blue');
    });
    it('array of objects with label and value', function () {
      var optionsObj = [{
        label: 'Red Color',
        value: 'red'
      }, {
        label: 'Green Color',
        value: 'green'
      }, {
        label: 'Blue Color',
        value: 'blue'
      }];
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        isOpen: true,
        options: optionsObj
      }));
      var $options = wrapper.find('.options');
      expect(wrapper.find('.dropdown')).toHaveLength(1);
      expect(wrapper.find('.options')).toHaveLength(1);
      expect(wrapper.find('.option')).toHaveLength(3);
      expect($options.childAt(0)).toHaveText('Red Color');
      expect($options.childAt(1)).toHaveText('Green Color');
      expect($options.childAt(2)).toHaveText('Blue Color');
    });
  });
  describe('open', function () {
    it('can start opened', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        isOpen: true
      }))).toHaveState('isOpen', true);
    });
    it('when trigger clicked', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options
      }));
      expect(wrapper).toHaveState('isOpen', false);
      wrapper.find('.trigger').first().simulate('click');
      expect(wrapper).toHaveState('isOpen', true);
    });
    it('when trigger key pressed space', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options
      }));
      var $trigger = wrapper.find('.trigger');
      expect(wrapper).toHaveState('isOpen', false);
      $trigger.first().simulate('keyup', {
        which: 32
      });
      expect(wrapper).toHaveState('isOpen', true);
    });
    it('when trigger key pressed enter', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options
      }));
      var $trigger = wrapper.find('.trigger');
      expect(wrapper).toHaveState('isOpen', false);
      $trigger.first().simulate('keyup', {
        which: 13
      });
      expect(wrapper).toHaveState('isOpen', true);
    });
  });
  describe('closes', function () {
    it('by default it\'s closed', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
        caption: "Menu"
      }))).toHaveState('isOpen', false);
    });
    it('when trigger key pressed space', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        isOpen: true,
        options: options
      }));
      var $trigger = wrapper.find('.trigger');
      expect(wrapper).toHaveState('isOpen', true);
      $trigger.first().simulate('keyup', {
        which: 32
      });
      expect(wrapper).toHaveState('isOpen', false);
    });
    it('when trigger key pressed enter', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        isOpen: true,
        options: options
      }));
      var $trigger = wrapper.find('.trigger');
      expect(wrapper).toHaveState('isOpen', true);
      $trigger.first().simulate('keyup', {
        which: 13
      });
      expect(wrapper).toHaveState('isOpen', false);
    });
    it('when trigger key pressed esc', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        isOpen: true,
        options: options
      }));
      var $trigger = wrapper.find('.trigger');
      expect(wrapper).toHaveState('isOpen', true);
      $trigger.first().simulate('keyup', {
        which: 27
      });
      expect(wrapper).toHaveState('isOpen', false);
    });
    it('on blur', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options
      }));
      wrapper.find('.trigger').first().simulate('click');
      expect(wrapper).toHaveState('isOpen', true);
      wrapper.find('.options').first().simulate('mousedown');
      wrapper.simulate('blur');
      expect(wrapper).toHaveState('isOpen', false);
      expect(wrapper.find('.options')).not.toExist();
    });
    it('when click outside', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options
      }));
      wrapper.find('.trigger').first().simulate('click');
      expect(wrapper).toHaveState('isOpen', true);
      document.body.click();
      expect(wrapper).toHaveState('isOpen', false);
      wrapper.update();
      expect(wrapper.find('.options')).not.toExist();
    });
    it('removes click outside listener', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options
      }));
      wrapper.instance().close = handler;
      wrapper.find('.trigger').first().simulate('click');
      wrapper.unmount();
      document.body.click();
      expect(handler).not.toHaveBeenCalled();
    });
    it('closes when option clicked', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options
      }));
      wrapper.find('.trigger').first().simulate('click');
      wrapper.find('.options').childAt(1).simulate('click');
      expect(wrapper).toHaveState('isOpen', false);
      expect(wrapper.find('.options')).not.toExist();
    });
  });
  describe('select', function () {
    it('when option clicked', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        onSelect: handler,
        options: options
      }));
      wrapper.find('.trigger').first().simulate('click');
      wrapper.find('.options').childAt(1).simulate('click');
      expect(handler).toHaveBeenCalled();
      expect(handler).toHaveBeenCalledWith('green');
    });
    it('when option press enter', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        onSelect: handler,
        options: options
      }));
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 13
      });
      wrapper.find('.options').childAt(1).simulate('keyup', {
        which: 13
      });
      expect(handler).toHaveBeenCalled();
      expect(handler).toHaveBeenCalledWith('green');
    });
    it('when option press space', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        onSelect: handler,
        options: options
      }));
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 32
      });
      wrapper.find('.options').childAt(1).simulate('keyup', {
        which: 32
      });
      expect(handler).toHaveBeenCalled();
      expect(handler).toHaveBeenCalledWith('green');
    });
    it('not when option press other key', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        onSelect: handler,
        options: options
      }));
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 32
      });
      wrapper.find('.options').childAt(1).simulate('keyup', {
        which: 33
      });
      expect(handler).not.toHaveBeenCalled();
    });
    it('cycling selection with arrows and press enter to select', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        onSelect: handler,
        options: options
      }));
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 32
      });
      wrapper.simulate('keyup', {
        which: 40
      });
      wrapper.simulate('keyup', {
        which: 40
      });
      wrapper.simulate('keyup', {
        which: 40
      });
      wrapper.simulate('keyup', {
        which: 38
      });
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 32
      });
      expect(handler).toHaveBeenCalled();
      expect(handler).toHaveBeenCalledWith('green');
    });
    it('cycling selection with arrows has limits on length', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        onSelect: handler,
        options: options
      }));
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 32
      });
      wrapper.simulate('keyup', {
        which: 40
      });
      wrapper.simulate('keyup', {
        which: 40
      });
      wrapper.simulate('keyup', {
        which: 40
      });
      expect(wrapper).toHaveState('optionFocused', 2);
      wrapper.simulate('keyup', {
        which: 40
      });
      expect(wrapper).toHaveState('optionFocused', 2);
      wrapper.simulate('keyup', {
        which: 38
      });
      expect(wrapper).toHaveState('optionFocused', 1);
      wrapper.simulate('keyup', {
        which: 38
      });
      expect(wrapper).toHaveState('optionFocused', 0);
      wrapper.simulate('keyup', {
        which: 38
      });
      expect(wrapper).toHaveState('optionFocused', 0);
    });
    it('cycling selection with arrows, then hover other option and press enter to select', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        onSelect: handler,
        options: options
      }));
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 32
      });
      wrapper.simulate('keyup', {
        which: 40
      });
      wrapper.find('.options').childAt(1).simulate('mouseover');
      wrapper.find('.trigger').first().simulate('keyup', {
        which: 32
      });
      expect(handler).toHaveBeenCalled();
      expect(handler).toHaveBeenCalledWith('green');
    });
  });
  describe('cap visible options', function () {
    it('maximum options visible', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options,
        size: 2
      }));
      wrapper.find('.trigger').first().simulate('click');
      expect(wrapper.find('.options')).toHaveStyle('overflowY', 'scroll');
      expect(wrapper.find('.options')).toHaveStyle('maxHeight', '120px');
    });
    it('when options less than size, dont\'t cap', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_dropdown.default, {
        caption: "Menu",
        options: options,
        size: 4
      }));
      wrapper.find('.trigger').first().simulate('click');
      expect(wrapper.find('.options')).not.toHaveStyle('overflowY', 'scroll');
      expect(wrapper.find('.options')).not.toHaveStyle('maxHeight', '120px');
    });
  });
  it('disable scroll on page', function () {
    var keyboardEvent = function keyboardEvent(keyCode) {
      return new window.KeyboardEvent('keydown', {
        bubbles: true,
        keyCode: keyCode
      });
    };

    var handler = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_dropdown.default, {
      caption: "Menu",
      options: options
    }), {
      attachTo: (0, _testUtils.setReactRoot)()
    });
    var $dropdown = wrapper.find('.dropdown');
    window.addEventListener('keydown', handler);
    $dropdown.instance().dispatchEvent(keyboardEvent(40));
    $dropdown.instance().dispatchEvent(keyboardEvent(38));
    $dropdown.instance().dispatchEvent(keyboardEvent(13));
    $dropdown.instance().dispatchEvent(keyboardEvent(32));
    expect(handler).not.toHaveBeenCalled();
    $dropdown.instance().dispatchEvent(keyboardEvent(31));
    expect(handler).toHaveBeenCalledTimes(1);
  });
});