"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _field = _interopRequireDefault(require("./field"));

var _select = _interopRequireDefault(require("./select"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Field', function () {
  describe('form element', function () {
    it('spans an input element', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, null)).find('input')).toHaveLength(1);
    });
    it('add field-element class', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, null)).find('.field-element')).toExist();
    });
    it('add id', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        id: "user"
      })).find('#user')).toExist();
    });
    it('add name', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        name: "user"
      })).find('input')).toHaveProp('name', 'user');
    });
    it('if no type then default to text', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, null)).find('input')).toHaveProp('type', 'text');
    });
    it('valid types', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "text"
      })).find('input[type="text"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "email"
      })).find('input[type="email"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "number"
      })).find('input[type="number"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "password"
      })).find('input[type="password"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "search"
      })).find('input[type="search"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "tel"
      })).find('input[type="tel"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "url"
      })).find('input[type="url"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "color"
      })).find('input[type="color"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "range"
      })).find('input[type="range"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "date"
      })).find('input[type="date"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "datetime-local"
      })).find('input[type="datetime-local"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "week"
      })).find('input[type="week"]')).toExist();
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        type: "month"
      })).find('input[type="month"]')).toExist();
    });
    it('set a default value', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        defaultValue: "Username"
      })).find('input')).toHaveProp('defaultValue', 'Username');
    });
    it('can be disabled', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        disabled: true,
        name: "user"
      }));
      expect(wrapper).toHaveClassName('disabled');
      expect(wrapper.find('input')).toHaveProp('disabled');
    });
    it('can be readonly', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        name: "user",
        readOnly: true
      }));
      expect(wrapper).toHaveClassName('readonly');
      expect(wrapper.find('input')).toHaveProp('readOnly');
    });
    it('can be a required field', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        required: true
      })).find('input')).toHaveProp('required');
    });
    it('a placeholder text can be set', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        placeholder: "User Name"
      })).find('input')).toHaveProp('placeholder', 'User Name');
    });
    it('a pattern validation can be set', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        pattern: "[a-zA-Z0-9]+"
      })).find('input')).toHaveProp('pattern', '[a-zA-Z0-9]+');
    });
    it('number validation attributes can be set', function () {
      var $input = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        max: 3,
        min: 1,
        step: 1,
        type: "number"
      })).find('input');
      expect($input).toHaveProp('max', 3);
      expect($input).toHaveProp('min', 1);
      expect($input).toHaveProp('step', 1);
    });
    it('text length validation attributes can be set', function () {
      var $input = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        maxLength: 3,
        minLength: 1
      })).find('input');
      expect($input).toHaveProp('maxLength', 3);
      expect($input).toHaveProp('minLength', 1);
    });
    it('other input attributes can be set', function () {
      var $input = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        autoComplete: true,
        autoFocus: true,
        size: 20,
        spellCheck: true,
        tabIndex: -1
      })).find('input');
      expect($input).toHaveProp('autoComplete');
      expect($input).toHaveProp('autoFocus');
      expect($input).toHaveProp('spellCheck');
      expect($input).toHaveProp('size', 20);
      expect($input).toHaveProp('tabIndex', -1);
    });
  });
  describe('label', function () {
    it('render', function () {
      var $label = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        id: "user",
        label: "User Name",
        name: "user"
      })).find('label');
      expect($label).toExist();
      expect($label).toHaveText('User Name');
      expect($label).toHaveProp('htmlFor', 'user');
    });
    it('not rendered by default', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, null)).find('label')).not.toExist();
    });
    it('when field is required has an icon', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        label: "User",
        name: "user",
        required: true
      }));
      var $icon = wrapper.find('.icon-required');
      expect($icon).toExist();
      expect($icon).toHaveProp('aria-label');
      expect($icon).toHaveProp('title');
      expect(wrapper.find('input')).toHaveProp('required');
    });
  });
  describe('display inline', function () {
    it('no divs present', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        id: "user",
        inline: true,
        name: "user"
      }));
      expect(wrapper).toHaveClassName('inline');
      expect(wrapper).not.toHaveDisplayName('div');
      expect(wrapper).toHaveDisplayName('span');
    });
    it('by default is full block', function () {
      expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, null))).not.toHaveClassName('inline');
    });
    it('when block no spans', function () {
      var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_field.default, {
        id: "user",
        label: "Username",
        name: "user"
      }));
      expect(wrapper).not.toHaveClassName('inline');
      expect(wrapper).toHaveDisplayName('div');
      expect(wrapper).not.toHaveDisplayName('span');
    });
  });
  describe('error message', function () {
    it('render', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "user",
        label: "User",
        name: "user",
        required: true
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      wrapper.update();
      var $input = wrapper.find('input');
      var $error = wrapper.find('.field-error');
      expect(wrapper.find('.field')).toHaveClassName('invalid');
      expect($error).toExist();
      expect($error).toHaveText('This is a required field.');
      expect($error).toHaveProp('id', 'user-error');
      expect($input).toHaveProp('aria-invalid', true);
      expect($input).toHaveProp('aria-describedby', 'user-error');
    });
    it('by default is hidden', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "user",
        label: "User",
        name: "user",
        required: true
      }));
      var $input = wrapper.find('input');
      expect(wrapper.find('.field-error')).not.toExist();
      expect(wrapper.find('.field')).not.toHaveClassName('invalid');
      expect($input).not.toHaveProp('aria-invalid');
      expect($input).not.toHaveProp('aria-describedby');
    });
    it('can be forced on mount', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "user",
        label: "User",
        name: "user",
        required: true,
        validate: true
      }));
      var $input = wrapper.find('input');
      expect(wrapper.find('.field-error')).toExist();
      expect(wrapper.find('.field')).toHaveClassName('invalid');
      expect($input).toHaveProp('aria-invalid');
      expect($input).toHaveProp('aria-describedby');
    });
  });
  describe('events', function () {
    it('onChange handler on simple input', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "user",
        name: "user",
        onChange: handler
      }));
      wrapper.find('input').first().simulate('change', {
        target: {
          value: 'Fernando'
        }
      });
      expect(handler).toHaveBeenCalled();
      expect(handler).toHaveBeenCalledWith('Fernando');
    });
    it('onChange handler on select input', function () {
      var handler = jest.fn();
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        component: "select",
        id: "color",
        label: "Choose a color",
        name: "color",
        onChange: handler,
        options: ['red', 'green', 'blue'],
        placeholder: "Choose a color"
      }));
      wrapper.find(_select.default).find('select').first().simulate('change', {
        target: {
          value: 'green'
        }
      });
      expect(handler).toHaveBeenCalled();
      expect(handler).toHaveBeenCalledWith('green');
    });
  });
  describe('validation', function () {
    it('if no invalid event then error hidden', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "email",
        name: "email",
        type: "email"
      }));
      var $input = wrapper.find('input');
      $input.instance().value = 'notanemail';
      $input.first().simulate('change', {
        target: {
          value: 'notanemail'
        }
      });
      expect(wrapper).toHaveState('invalid', false);
      expect(wrapper).toHaveState('errorMessage', '');
      expect(wrapper.find('.field-error')).not.toExist();
    });
    it('if onchange before invalid then error hidden', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "email",
        name: "email",
        type: "email"
      }));
      var $input = wrapper.find('input');
      $input.instance().value = 'notanemail';
      $input.first().simulate('change', {
        target: {
          value: 'notanemail'
        }
      });
      expect(wrapper).toHaveState('invalid', false);
      expect(wrapper).toHaveState('errorMessage', ''); // Activate validation and show message

      $input.instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This value is not an email.');
    });
    it('onchange after invalid can make the error go away', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "email",
        name: "email",
        type: "email"
      }));
      var $input = wrapper.find('input'); // Input invalid data

      $input.instance().value = 'notanemail';
      $input.first().simulate('change', {
        target: {
          value: 'notanemail'
        }
      }); // Activate validation

      $input.instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This value is not an email.'); // Input correct data

      $input.instance().value = 'email@domain.com';
      $input.first().simulate('change', {
        target: {
          value: 'email@domain.com'
        }
      });
      expect(wrapper).toHaveState('invalid', false);
      expect(wrapper).toHaveState('errorMessage', '');
    });
    it.skip('if validate prop then do validation from mount', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        defaultValue: "notanemail",
        id: "email",
        name: "email",
        type: "email",
        validate: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This value is not an email.');
    });
    it('required', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "user",
        name: "user",
        required: true
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This is a required field.');
    });
    it('type', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        defaultValue: "notanemail",
        id: "email",
        name: "email",
        type: "email"
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This value is not an email.');
    });
    it('pattern', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        defaultValue: "(11)123456789",
        id: "tel",
        name: "tel",
        pattern: "^[\\d]*$",
        type: "tel"
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This value is invalid.');
    });
    it('required comes before type', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        id: "email",
        name: "email",
        required: true,
        type: "email"
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This is a required field.');
    });
    it('type comes before pattern', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        defaultValue: "notanemail",
        id: "email",
        name: "email",
        pattern: "^[\\d]*$",
        type: "email"
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'This value is not an email.');
    });
    it('required custom error message', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        errorMessages: {
          valueMissing: 'You must input this field.'
        },
        id: "user",
        name: "user",
        required: true
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'You must input this field.');
    });
    it('type custom error message', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        defaultValue: "notanemail",
        errorMessages: {
          typeMismatch: 'You did not input an email value.'
        },
        id: "email",
        name: "email",
        type: "email"
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'You did not input an email value.');
    });
    it('pattern custom error message', function () {
      var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
        defaultValue: "(11)123456789",
        errorMessages: {
          patternMismatch: 'You input an invalid value.'
        },
        id: "tel",
        name: "tel",
        pattern: "^[\\d]*$",
        type: "tel"
      }));
      wrapper.find('input').instance().dispatchEvent(new window.Event('invalid', {
        bubbles: true
      }));
      expect(wrapper).toHaveState('invalid', true);
      expect(wrapper).toHaveState('errorMessage', 'You input an invalid value.');
    });
    describe('Multiline or textarea', function () {
      it('wrap a textarea element', function () {
        expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
          id: "comments",
          multiLine: true,
          name: "comments"
        })).find('textarea')).toHaveLength(1);
        expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
          component: "textarea",
          id: "comments",
          name: "comments"
        })).find('textarea')).toHaveLength(1);
      });
      it('resize', function () {
        expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
          id: "comments",
          multiLine: true,
          name: "comments"
        })).find('textarea')).toHaveStyle('resize', 'none');
        expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
          id: "comments",
          multiLine: true,
          name: "comments",
          resize: true
        })).find('textarea')).toHaveStyle('resize', 'both');
        expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
          id: "comments",
          multiLine: true,
          name: "comments",
          resize: "vertical"
        })).find('textarea')).toHaveStyle('resize', 'vertical');
      });
    });
    describe('Select Field', function () {
      it('wrap a select component', function () {
        expect((0, _enzyme.shallow)(_react.default.createElement(_field.default, {
          component: "select",
          id: "color",
          label: "Choose a color",
          name: "color",
          options: ['red', 'green', 'blue'],
          placeholder: "Choose a color"
        })).find(_select.default)).toExist();
      });
      it('if no invalid event then error hidden', function () {
        var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
          component: "select",
          id: "color",
          name: "color",
          options: ['red', 'green', 'blue'],
          placeholder: "Choose a color",
          required: true
        }));
        var $select = wrapper.find('select');
        $select.instance().value = 'red';
        $select.first().simulate('change', {
          target: {
            value: 'red'
          }
        });
        expect(wrapper).toHaveState('invalid', false);
        expect(wrapper).toHaveState('errorMessage', '');
        expect(wrapper.find('.field-error')).not.toExist();
      });
      it('if onchange before invalid then error hidden', function () {
        var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
          component: "select",
          id: "color",
          name: "color",
          options: ['red', 'green', 'blue'],
          placeholder: "Choose a color",
          required: true
        }));
        var $select = wrapper.find('select');
        expect(wrapper).toHaveState('invalid', false);
        expect(wrapper).toHaveState('errorMessage', ''); // Activate validation and show message

        $select.instance().dispatchEvent(new window.Event('invalid', {
          bubbles: true
        }));
        expect(wrapper).toHaveState('invalid', true);
        expect(wrapper).toHaveState('errorMessage', 'This is a required field.');
      });
      it('onchange after invalid can make the error go away', function () {
        var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
          component: "select",
          id: "color",
          name: "color",
          options: ['red', 'green', 'blue'],
          placeholder: "Choose a color",
          required: true
        }));
        var $select = wrapper.find('select'); // Activate validation

        $select.instance().dispatchEvent(new window.Event('invalid', {
          bubbles: true
        }));
        expect(wrapper).toHaveState('invalid', true);
        expect(wrapper).toHaveState('errorMessage', 'This is a required field.'); // Input correct data

        $select.instance().value = 'red';
        $select.first().simulate('change', {
          target: {
            value: 'red'
          }
        });
        expect(wrapper).toHaveState('invalid', false);
        expect(wrapper).toHaveState('errorMessage', '');
      });
      it.skip('if validate prop then do validation from mount', function () {
        var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
          component: "select",
          id: "color",
          name: "color",
          options: ['red', 'green', 'blue'],
          placeholder: "Choose a color",
          required: true,
          validate: true
        }));
        expect(wrapper).toHaveState('invalid', true);
        expect(wrapper).toHaveState('errorMessage', 'This is a required field.');
      });
      it.skip('required', function () {
        var wrapper = (0, _enzyme.mount)(_react.default.createElement(_field.default, {
          component: "select",
          id: "color",
          name: "color",
          options: ['red', 'green', 'blue'],
          placeholder: "Choose a color",
          required: true,
          validate: true
        }));
        wrapper.find('select').instance().dispatchEvent(new window.Event('invalid', {
          bubbles: true
        }));
        expect(wrapper).toHaveState('invalid', true);
        expect(wrapper).toHaveState('errorMessage', 'This is a required field.');
      });
    });
  });
});