"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _react = _interopRequireWildcard(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactChildrenUtilities = _interopRequireDefault(require("react-children-utilities"));

require("./form.scss");

var _field = _interopRequireDefault(require("./field"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _typeof(obj) { if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

/**
 * Form
 * Wraps fields in order to make a form with a submit
 */
var Form =
/*#__PURE__*/
function (_Component) {
  _inherits(Form, _Component);

  /**
   * Constructor
   * @param {Object} props - React props
   */
  function Form(props) {
    var _this;

    _classCallCheck(this, Form);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Form).call(this, props));
    _this.state = {
      values: {}
    };
    _this.handleFieldChange = _this.handleFieldChange.bind(_assertThisInitialized(_this));
    _this.handleSubmit = _this.handleSubmit.bind(_assertThisInitialized(_this));
    _this.handleReset = _this.handleReset.bind(_assertThisInitialized(_this));
    return _this;
  }
  /**
   * Update state from onChange fields event
   * @param     {string} fieldName - Name from a Field included in Form
   * @returns {function}           - Change event handler
   */


  _createClass(Form, [{
    key: "handleFieldChange",
    value: function handleFieldChange(fieldName) {
      var _this2 = this;

      return function (event) {
        var values = _this2.state.values;
        values[fieldName] = event.target && event.target.value ? event.target.value : event;

        _this2.setState({
          values: values
        });
      };
    }
    /**
     * Handle Form submit
     * @param {object} event - DOM event object
     */

  }, {
    key: "handleReset",
    value: function handleReset(event) {
      var onReset = this.props.onReset;
      this.setState({
        values: {}
      });

      if (onReset) {
        onReset(event);
      }
    }
    /**
     * Handle Form submit
     * @param {object} event - DOM event object
     */

  }, {
    key: "handleSubmit",
    value: function handleSubmit(event) {
      event.preventDefault();
      var onSubmit = this.props.onSubmit;
      var values = this.state.values;

      if (onSubmit) {
        onSubmit(values);
      }
    }
    /**
     * Render method
     * @returns {JSX} - Component template
     */

  }, {
    key: "render",
    value: function render() {
      var _this3 = this;

      var children = this.props.children;

      var formChildren = _reactChildrenUtilities.default.deepMap(children, function (child) {
        if (child.type === _field.default) {
          return (0, _react.cloneElement)(child, _objectSpread({}, child.props, {
            onChange: _this3.handleFieldChange(child.props.name)
          }));
        }

        return child;
      });

      var grouped = _reactChildrenUtilities.default.groupByType(formChildren, ['footer'], 'body');

      return _react.default.createElement("form", {
        onReset: this.handleReset,
        onSubmit: this.handleSubmit
      }, grouped.body, grouped.footer && _react.default.createElement("div", {
        className: "form-footer"
      }, grouped.footer));
    }
  }]);

  return Form;
}(_react.Component);

exports.default = Form;
Form.propTypes = {
  children: _propTypes.default.node,
  onReset: _propTypes.default.func,
  onSubmit: _propTypes.default.func
};