"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _button = _interopRequireDefault(require("../button/button"));

var _field = _interopRequireDefault(require("./field"));

var _form = _interopRequireDefault(require("./form"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var setupExample = function setupExample(props) {
  return _react.default.createElement(_form.default, props, _react.default.createElement(_field.default, {
    id: "firstName",
    name: "firstName"
  }), _react.default.createElement(_field.default, {
    id: "lastName",
    name: "lastName"
  }), _react.default.createElement(_field.default, {
    id: "email",
    name: "email",
    type: "email"
  }), _react.default.createElement("footer", null, _react.default.createElement(_button.default, {
    caption: "Send",
    display: "primary",
    type: "submit"
  }), _react.default.createElement(_button.default, {
    caption: "Clear",
    type: "reset"
  })));
};

describe('Form', function () {
  it('wraps children with a form element', function () {
    var wrapper = (0, _enzyme.shallow)(setupExample());
    expect(wrapper.find('form')).toHaveLength(1);
    expect(wrapper.find(_field.default)).toHaveLength(3);
    expect(wrapper.find(_button.default)).toHaveLength(2);
  });
  it('form footer', function () {
    var wrapper = (0, _enzyme.shallow)(setupExample());
    expect(wrapper.find('footer')).not.toExist();
    expect(wrapper.find('.form-footer')).toHaveLength(1);
    expect(wrapper.find(_button.default)).toHaveLength(2);
    expect(wrapper.find('.form-footer').find(_button.default)).toHaveLength(2);
    expect(wrapper.find('.form-footer').find(_field.default)).not.toExist();
  });
  it('set state when any field updates', function () {
    var wrapper = (0, _enzyme.shallow)(setupExample());
    wrapper.find('[name="firstName"]').first().simulate('change', {
      target: {
        value: 'Fernando'
      }
    });
    wrapper.find('[name="lastName"]').first().simulate('change', {
      target: {
        value: 'Pasik'
      }
    });
    wrapper.find('[name="email"]').first().simulate('change', {
      target: {
        value: 'fernando@pasik.com.ar'
      }
    });
    expect(wrapper).toHaveState('values', {
      firstName: 'Fernando',
      lastName: 'Pasik',
      email: 'fernando@pasik.com.ar'
    });
  });
  it('submit event', function () {
    var callback = jest.fn();
    var wrapper = (0, _enzyme.mount)(setupExample({
      onSubmit: callback
    }));
    wrapper.find('form').first().simulate('submit');
    expect(callback).toHaveBeenCalled();
  });
  it.skip('submit event handler receives object with fields', function () {
    var callback = jest.fn();
    var wrapper = (0, _enzyme.mount)(setupExample({
      onSubmit: callback
    }));
    wrapper.find('[name="firstName"]').first().simulate('change', {
      target: {
        value: 'Fernando'
      }
    });
    wrapper.find('[name="lastName"]').first().simulate('change', {
      target: {
        value: 'Pasik'
      }
    });
    wrapper.find('[name="email"]').first().simulate('change', {
      target: {
        value: 'fernando@pasik.com.ar'
      }
    });
    wrapper.find('form').first().simulate('submit');
    expect(callback).toHaveBeenCalled();
    expect(callback).toHaveBeenCalledWith({
      firstName: 'Fernando',
      lastName: 'Pasik',
      email: 'fernando@pasik.com.ar'
    });
  });
  it('clears the state on reset event', function () {
    var callback = jest.fn();
    var wrapper = (0, _enzyme.mount)(setupExample({
      onReset: callback
    }));
    wrapper.find('[name="firstName"]').first().simulate('change', {
      target: {
        value: 'Fernando'
      }
    });
    wrapper.find('[name="lastName"]').first().simulate('change', {
      target: {
        value: 'Pasik'
      }
    });
    wrapper.find('[name="email"]').first().simulate('change', {
      target: {
        value: 'fernando@pasik.com.ar'
      }
    });
    wrapper.find('form').first().simulate('reset');
    expect(callback).toHaveBeenCalled();
  });
});