"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _dropdown = _interopRequireDefault(require("../dropdown/dropdown"));

var _select = _interopRequireDefault(require("./select"));

var _testUtils = require("../utils/test-utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var options = ['red', 'green', 'blue'];
describe('Select', function () {
  it('select element without options', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_select.default, null));
    expect(wrapper.find('select')).toExist();
    expect(wrapper.find(_dropdown.default)).toExist();
    expect(wrapper.find('option')).not.toExist();
    expect(wrapper.find('.option')).not.toExist();
    expect(wrapper.find('.options')).not.toExist();
  });
  it('placeholder message for empty option', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_select.default, {
      placeholder: "Pick a color"
    }));
    var $select = wrapper.find('select');
    expect(wrapper.find('select')).toExist();
    expect(wrapper.find('option')).toHaveLength(1);
    expect($select.childAt(0)).toHaveValue('');
    expect($select.childAt(0)).toHaveText('Pick a color');
    expect(wrapper.find('.selected-option')).toHaveText('Pick a color');
  });
  it('with options as an array of strings', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_select.default, {
      options: options,
      placeholder: "Pick a color"
    }));
    var $select = wrapper.find('select');
    expect(wrapper.find('option')).toHaveLength(4);
    expect($select.childAt(0)).toHaveValue('');
    expect($select.childAt(0)).toHaveText('Pick a color');
    expect($select.childAt(1)).toHaveValue('red');
    expect($select.childAt(1)).toHaveText('red');
    expect($select.childAt(2)).toHaveValue('green');
    expect($select.childAt(2)).toHaveText('green');
    expect($select.childAt(3)).toHaveValue('blue');
    expect($select.childAt(3)).toHaveText('blue');
    wrapper.find('.selected-option').first().simulate('click');
    var $fakeSelect = wrapper.find('.options');
    expect(wrapper.find('.option')).toHaveLength(4);
    expect($fakeSelect.childAt(0)).toHaveText('Pick a color');
    expect($fakeSelect.childAt(1)).toHaveText('red');
    expect($fakeSelect.childAt(2)).toHaveText('green');
    expect($fakeSelect.childAt(3)).toHaveText('blue');
  });
  it('with options as an array of objects with label and value', function () {
    var optionsObj = [{
      label: 'Red Color',
      value: 'red'
    }, {
      label: 'Green Color',
      value: 'green'
    }, {
      label: 'Blue Color',
      value: 'blue'
    }];
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_select.default, {
      options: optionsObj,
      placeholder: "Pick a color"
    }));
    var $select = wrapper.find('select');
    expect(wrapper.find('option')).toHaveLength(4);
    expect($select.childAt(0)).toHaveValue('');
    expect($select.childAt(0)).toHaveText('Pick a color');
    expect($select.childAt(1)).toHaveValue('red');
    expect($select.childAt(1)).toHaveText('Red Color');
    expect($select.childAt(2)).toHaveValue('green');
    expect($select.childAt(2)).toHaveText('Green Color');
    expect($select.childAt(3)).toHaveValue('blue');
    expect($select.childAt(3)).toHaveText('Blue Color');
    wrapper.find('.selected-option').first().simulate('click');
    var $fakeSelect = wrapper.find('.options');
    expect(wrapper.find('.option')).toHaveLength(4);
    expect($fakeSelect.childAt(0)).toHaveText('Pick a color');
    expect($fakeSelect.childAt(1)).toHaveText('Red Color');
    expect($fakeSelect.childAt(2)).toHaveText('Green Color');
    expect($fakeSelect.childAt(3)).toHaveText('Blue Color');
  });
  it('selected value through select element', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_select.default, {
      options: options,
      placeholder: "Pick a color"
    }));
    var $select = wrapper.find('select');
    var $fakeSelectOption = wrapper.find('.selected-option');
    expect($select.instance().value).toEqual('');
    expect($fakeSelectOption).toHaveText('Pick a color');
    $select.instance().value = 'blue';
    $select.first().simulate('change', {
      target: {
        value: 'blue'
      }
    });
    expect(wrapper).toHaveState('value', 'blue');
    expect($fakeSelectOption).toHaveText('blue');
    expect($select.instance().value).toEqual('blue');
  });
  it('selected value through fake select click', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_select.default, {
      options: options,
      placeholder: "Pick a color"
    }));
    var $select = wrapper.find('select');
    var $fakeSelectOption = wrapper.find('.selected-option');
    expect($select.instance().value).toEqual('');
    expect($fakeSelectOption).toHaveText('Pick a color');
    wrapper.find('.trigger').first().simulate('click');
    wrapper.find('.options').childAt(2).simulate('click');
    expect(wrapper).toHaveState('value', 'green');
    expect($fakeSelectOption).toHaveText('green');
    expect($select.instance().value).toEqual('green');
  });
  it('onChange handler through select change', function () {
    var handler = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_select.default, {
      onChange: handler,
      options: options,
      placeholder: "Choose"
    }));
    var $select = wrapper.find('select');
    var $fakeSelectOption = wrapper.find('.selected-option');
    expect($select.instance().value).toEqual('');
    expect($fakeSelectOption).toHaveText('Choose');
    $select.instance().value = 'blue';
    $select.first().simulate('change', {
      target: {
        value: 'blue'
      }
    });
    expect(wrapper).toHaveState('value', 'blue');
    expect($fakeSelectOption).toHaveText('blue');
    expect($select.instance().value).toEqual('blue');
    expect(handler).toHaveBeenCalledTimes(1);
    expect(handler).toHaveBeenCalledWith(expect.objectContaining({
      target: {
        value: 'blue'
      }
    }));
  });
  it.skip('onChange handler through fake select click', function () {
    var handler = jest.fn();
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_select.default, {
      onChange: handler,
      options: options,
      placeholder: "Choose"
    }), {
      attachTo: (0, _testUtils.setReactRoot)()
    });
    var $select = wrapper.find('select');
    var $fakeSelectOption = wrapper.find('.selected-option');
    expect($select.instance().value).toEqual('');
    expect($fakeSelectOption).toHaveText('Choose');
    wrapper.find('.trigger').first().simulate('click');
    wrapper.find('.options').childAt(2).simulate('click');
    expect(wrapper).toHaveState('value', 'green');
    expect($fakeSelectOption).toHaveText('green');
    expect($select.instance().value).toEqual('green');
    expect(handler).toHaveBeenCalledWith(expect.objectContaining({
      target: {
        value: 'green'
      }
    }));
    expect(handler).toHaveBeenCalledTimes(1);
  });
  it('onFocus and onBlur sets style', function () {
    var wrapper = (0, _enzyme.mount)(_react.default.createElement(_select.default, {
      options: options,
      placeholder: "Choose"
    }));
    var $select = wrapper.find('select');
    expect(wrapper.find('.selected-option')).not.toHaveClassName('focus');
    $select.first().simulate('focus');
    expect(wrapper.find('.selected-option')).toHaveClassName('focus');
    $select.first().simulate('blur');
    expect(wrapper.find('.selected-option')).not.toHaveClassName('focus');
  });
});