"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = Panel;

var _react = _interopRequireDefault(require("react"));

var _propTypes = _interopRequireDefault(require("prop-types"));

var _reactChildrenUtilities = _interopRequireDefault(require("react-children-utilities"));

require("./panel.scss");

var _collapsible = _interopRequireDefault(require("../collapsible/collapsible"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Panel
 * @param   {Object} props     - React props
 * @returns    {JSX} template  - Component template
 */
function Panel(props) {
  var children = props.children,
      collapsed = props.collapsed,
      id = props.id,
      title = props.title;

  var grouped = _reactChildrenUtilities.default.groupByType(children, ['header', 'footer'], 'body');

  if (!title && !grouped.header && !grouped.footer) {
    return _react.default.createElement("div", {
      className: "panel panel-body"
    }, children);
  }

  return _react.default.createElement("div", {
    className: "panel"
  }, (title || grouped.header) && _react.default.createElement("div", {
    "aria-controls": id && "".concat(id, "-body"),
    "aria-expanded": !collapsed,
    className: "panel-header",
    id: id && "".concat(id, "-title")
  }, title || grouped.header), _react.default.createElement(_collapsible.default, {
    collapsed: collapsed
  }, _react.default.createElement("div", {
    className: "panel-content"
  }, _react.default.createElement("div", {
    "aria-labelledby": id && "".concat(id, "-title"),
    className: "panel-body",
    id: id && "".concat(id, "-body")
  }, grouped.body), grouped.footer && _react.default.createElement("div", {
    className: "panel-footer"
  }, grouped.footer))));
}

Panel.propTypes = {
  children: _propTypes.default.node,
  collapsed: _propTypes.default.bool,
  id: _propTypes.default.string,
  title: _propTypes.default.string
};