"use strict";

var _react = _interopRequireDefault(require("react"));

var _enzyme = require("enzyme");

var _panel = _interopRequireDefault(require("./panel"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('Panel', function () {
  it('it\'s a box that wraps content', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_panel.default, null, "This is content"));
    expect(wrapper.find('.panel')).toHaveText('This is content');
  });
  it('can have a title prop', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_panel.default, {
      title: "Example title"
    }, "This is content"));
    expect(wrapper.find('.panel-header')).toExist();
    expect(wrapper.find('.panel-header')).toHaveText('Example title');
    expect(wrapper.find('.panel-body')).toExist();
    expect(wrapper.find('.panel.panel-body')).not.toExist();
  });
  it('can have html content in header', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_panel.default, null, _react.default.createElement("header", null, _react.default.createElement("h2", null, "Example title")), "This is content"));
    expect(wrapper.find('.panel-header')).toExist();
    expect(wrapper.find('.panel-header h2')).toExist();
    expect(wrapper.find('.panel-header header')).not.toExist();
    expect(wrapper.find('.panel-body')).toExist();
    expect(wrapper.find('.panel-body')).toHaveText('This is content');
    expect(wrapper.find('.panel-footer')).not.toExist();
  });
  it('can have html content in footer', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_panel.default, null, "This is content", _react.default.createElement("footer", null, _react.default.createElement("button", {
      type: "button"
    }, "OK"))));
    expect(wrapper.find('.panel-footer')).toExist();
    expect(wrapper.find('.panel-footer button')).toExist();
    expect(wrapper.find('.panel-footer footer')).not.toExist();
    expect(wrapper.find('.panel-body')).toExist();
    expect(wrapper.find('.panel-body')).toHaveText('This is content');
    expect(wrapper.find('.panel-header')).not.toExist();
  });
  it('when no footer and header present it\'s just content', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_panel.default, null, "This is content"));
    expect(wrapper.find('.panel-header')).not.toExist();
    expect(wrapper.find('.panel-footer')).not.toExist();
    expect(wrapper.find('.panel.panel-body')).toExist();
    expect(wrapper.find('.panel.panel-body')).toHaveText('This is content');
  });
  it('if collapsible, add accessibility tags', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_panel.default, {
      collapsible: true,
      id: "example"
    }, _react.default.createElement("header", null, _react.default.createElement("h2", null, "Example title")), "This is content"));
    expect(wrapper.find('.panel-header')).toMatchSelector('[aria-expanded=true]');
    expect(wrapper.find('.panel-header')).toMatchSelector('[aria-controls="example-body"]');
    expect(wrapper.find('.panel-body')).toMatchSelector('[aria-labelledby="example-title"]');
  });
  it('could be collapsed', function () {
    var wrapper = (0, _enzyme.shallow)(_react.default.createElement(_panel.default, {
      collapsed: true,
      id: "example"
    }, _react.default.createElement("header", null, _react.default.createElement("h2", null, "Example title")), "This is content"));
    expect(wrapper.find('.panel-header')).toMatchSelector('[aria-expanded=false]');
    expect(wrapper.find('.panel-header')).toMatchSelector('[aria-controls="example-body"]');
    expect(wrapper.find('.panel-body')).toMatchSelector('[aria-labelledby="example-title"]');
  });
});